@@ -22,7 +22,6 @@
 
 #include <gpe/init.h>
 #include <gpe/pixmaps.h>
-#include <gpe/render.h>
 #include <gpe/errorbox.h>
 
 #include <gpe/event-db.h>
@@ -93,7 +92,7 @@ days_in_month (guint year, guint month)
 }
 
 time_t
-time_from_day(int year, int month, int day)
+time_from_day (int year, int month, int day)
 {
   struct tm tm;
   time_t selected_time;
@@ -101,9 +100,6 @@ time_from_day(int year, int month, int day)
   tm.tm_year = year;
   tm.tm_mon = month;
   tm.tm_mday = day;
-  tm.tm_hour = 0;
-  tm.tm_min = 0;
-  tm.tm_sec = 0;
   selected_time = mktime (&tm);
   return selected_time;
 }
@@ -113,12 +109,15 @@ set_time_all_views(void)
 {
   gpointer ds;
   
-  ds = g_object_get_data(G_OBJECT(main_window),"datesel-week");
-  gtk_date_sel_set_time(GTK_DATE_SEL(ds),viewtime);
-  ds = g_object_get_data(G_OBJECT(main_window),"datesel-month");
-  gtk_date_sel_set_time(GTK_DATE_SEL(ds),viewtime);
-  ds = g_object_get_data(G_OBJECT(main_window),"datesel-day");
-  gtk_date_sel_set_time(GTK_DATE_SEL(ds),viewtime);
+  ds = g_object_get_data (G_OBJECT (main_window), "datesel-week");
+  if (ds)
+    gtk_date_sel_set_time(GTK_DATE_SEL (ds), viewtime);
+  ds = g_object_get_data (G_OBJECT (main_window), "datesel-month");
+  if (ds)
+    gtk_date_sel_set_time (GTK_DATE_SEL (ds), viewtime);
+  ds = g_object_get_data(G_OBJECT (main_window), "datesel-day");
+  if (ds)
+    gtk_date_sel_set_time (GTK_DATE_SEL (ds), viewtime);
 }
 
 void
